<?php
/*
= LuxCal configuration =
*/
$lcV="5.3.4M"; //LuxCal version
$dbType="MySQL"; //db type (MySQL or SQLite)
$dbHost="[[softdbhost]]"; //MySQL server
$dbUnam="[[softdbuser]]"; //database username
$dbPwrd="[[softdbpass]]"; //database password
$dbName="[[softdb]]"; //database name
$dbDef="mycal"; //default calendar (name)
$crHost=0; //0:local, 1:remote, 2:remote+IP address
$crIpAd=""; //IP address of remote cron service
?>